==> google-cloud-automl-2.5.2.tar.gz: google-cloud-automl-2.5.2/google/cloud/automl_v1beta1/types/video.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.cloud.automl.v1beta1",
    manifest={
        "VideoClassificationDatasetMetadata",
        "VideoObjectTrackingDatasetMetadata",
        "VideoClassificationModelMetadata",
        "VideoObjectTrackingModelMetadata",
    },
)


class VideoClassificationDatasetMetadata(proto.Message):
    r"""Dataset metadata specific to video classification.
    All Video Classification datasets are treated as multi label.

    """


class VideoObjectTrackingDatasetMetadata(proto.Message):
    r"""Dataset metadata specific to video object tracking.
    """


class VideoClassificationModelMetadata(proto.Message):
    r"""Model metadata specific to video classification.
    """


class VideoObjectTrackingModelMetadata(proto.Message):
    r"""Model metadata specific to video object tracking.
    """


__all__ = tuple(sorted(__protobuf__.manifest))

==> google-cloud-automl-2.13.4.tar.gz: google-cloud-automl-2.13.4/google/cloud/automl_v1beta1/types/video.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.automl.v1beta1",
    manifest={
        "VideoClassificationDatasetMetadata",
        "VideoObjectTrackingDatasetMetadata",
        "VideoClassificationModelMetadata",
        "VideoObjectTrackingModelMetadata",
    },
)


class VideoClassificationDatasetMetadata(proto.Message):
    r"""Dataset metadata specific to video classification.
    All Video Classification datasets are treated as multi label.

    """


class VideoObjectTrackingDatasetMetadata(proto.Message):
    r"""Dataset metadata specific to video object tracking."""


class VideoClassificationModelMetadata(proto.Message):
    r"""Model metadata specific to video classification."""


class VideoObjectTrackingModelMetadata(proto.Message):
    r"""Model metadata specific to video object tracking."""


__all__ = tuple(sorted(__protobuf__.manifest))
